@@ -1,3 +1,7 @@
+import warnings
+
+warnings.filterwarnings("ignore")
+
 import cython
 import pyximport; pyximport.install()
 import pandas as pd
@@ -11,11 +15,9 @@ import os
 import sys
 from io import StringIO
 from math import floor
-from alacorder import run
-from alacorder import alac
-import warnings
+import run
+import alac
 
-warnings.filterwarnings("ignore")
 
 print('''
 
@@ -26,7 +28,7 @@ print('''
 	/_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
 																																														
 		
-		ALACORDER beta 0.6.0
+		ALACORDER beta 0.6.2
 		by Sam Robson	
 
 
